<?php $TRANSLATIONS = array(
"OpenID Changed" => "تم تغيير ال OpenID",
"Invalid request" => "طلبك غير مفهوم",
"Language changed" => "تم تغيير اللغة",
"__language_name__" => "__language_name__",
"Select an App" => "إختر تطبيقاً",
"Ask a question" => "إسأل سؤال",
"Problems connecting to help database." => "الاتصال بقاعدة بيانات المساعدة لم يتم بنجاح",
"Go there manually." => "إذهب هنالك بنفسك",
"Answer" => "الجواب",
"Unable to change your password" => "لم يتم تعديل كلمة السر بنجاح",
"Current password" => "كلمات السر الحالية",
"New password" => "كلمات سر جديدة",
"show" => "أظهر",
"Change password" => "عدل كلمة السر",
"Email" => "العنوان البريدي",
"Your email address" => "عنوانك البريدي",
"Fill in an email address to enable password recovery" => "أدخل عنوانك البريدي لتفعيل استرجاع كلمة المرور",
"Language" => "اللغة",
"Help translate" => "ساعد في الترجمه",
"use this address to connect to your ownCloud in your file manager" => "إستخدم هذا العنوان للإتصال ب ownCloud داخل نظام الملفات ",
"Name" => "الاسم",
"Password" => "كلمات السر",
"Groups" => "مجموعات",
"Create" => "انشئ",
"Quota" => "حصه",
"Delete" => "حذف"
);
